==> vmtk_0.9.0.orig.tar.gz: vmtk-0.9.0/vmtkScripts/vmtkscripts.py <==
__all__ = [
  'vmtkactivetubes',
  'vmtkbifurcationprofiles',
  'vmtkbifurcationreferencesystems',
  'vmtkbifurcationsections',
  'vmtkbifurcationvectors',
  'vmtkboundarylayer',
  'vmtkboundaryreferencesystems',
  'vmtkbranchclipper',
  'vmtkbranchextractor',
  'vmtkbranchgeometry',
  'vmtkbranchmapping',
  'vmtkbranchmetrics',
  'vmtkbranchpatching',
  'vmtkbranchsections',
  'vmtkcenterlineattributes',
  'vmtkcenterlinegeometry',
  'vmtkcenterlinelabeler',
  'vmtkcenterlinemerge',
  'vmtkcenterlinemodeller',
  'vmtkcenterlineoffsetattributes',
  'vmtkcenterlineresampling',
  'vmtkcenterlines',
  'vmtkcenterlinesections',
  'vmtkcenterlinesmoothing',
  'vmtkcenterlineviewer',
  'vmtkdelaunayvoronoi',
  'vmtkdistancetocenterlines',
  'vmtkendpointextractor',
  'vmtkflowextensions',
  'vmtkicpregistration',
  'vmtkimagecast',
  'vmtkimagecompose',
  'vmtkimagecurvedmpr',
  'vmtkimagefeaturecorrection',
  'vmtkimagefeatures',
  'vmtkimageinitialization',
  'vmtkimagelinetracer',
  'vmtkimagemipviewer',
  'vmtkimageobjectenhancement',
  'vmtkimagereader',
  'vmtkimagereslice',
  'vmtkimageseeder',
  'vmtkimageshiftscale',
  'vmtkimagesmoothing',
  'vmtkimageviewer',
  'vmtkimagevesselenhancement',
  'vmtkimagevoipainter',
  'vmtkimagevoiselector',
  'vmtkimagewriter',
  'vmtklevelsetsegmentation',
  'vmtklineartoquadratic',
  'vmtklineresampling',
  'vmtklocalgeometry',
  'vmtkmarchingcubes',
  'vmtkmeshboundaryinspector',
  'vmtkmeshclipper',
  'vmtkmeshdatareader',
  'vmtkmeshlinearize',
  'vmtkmeshgenerator',
  'vmtkmeshprojection',
  'vmtkmeshreader',
  'vmtkmeshscaling',
  'vmtkmeshtetrahedralize',
  'vmtkmeshtosurface',
  'vmtkmeshtransform',
  'vmtkmeshtransformtoras',
  'vmtkmeshviewer',
  'vmtkmeshwriter',
  'vmtknetworkeditor',
  'vmtknetworkextraction',
  'vmtknetworkwriter',
  'vmtkpointsplitextractor',
  'vmtkpointtransform',
  'vmtkpolyballmodeller',
  'vmtkpotentialfit',
  'vmtkpythonscript',
  'vmtkrenderer',
  'vmtkrendertoimage',
  'vmtkrbfinterpolation',
  'vmtksurfaceappend',
  'vmtksurfacecapper',
  'vmtksurfacecelldatatopointdata',
  'vmtksurfacecenterlineprojection',
  'vmtksurfaceclipper',
  'vmtksurfaceconnectivity',
  'vmtksurfacedecimation',
  'vmtksurfacedistance',
  'vmtksurfacekiteremoval',
  'vmtksurfacemodeller',
  'vmtksurfacenormals',
  'vmtksurfaceprojection',
  'vmtksurfacereader',
  'vmtksurfacereferencesystemtransform',
  'vmtksurfaceremeshing',
  'vmtksurfacescaling',
  'vmtksurfacesmoothing',
  'vmtksurfacesubdivision',
  'vmtksurfacetransform',
  'vmtksurfacetransforminteractive',
  'vmtksurfacetransformtoras',
  'vmtksurfacetriangle',
  'vmtksurfacetomesh',
  'vmtksurfaceviewer',
  'vmtksurfacewriter',
  'vmtksurfmesh',
  'vmtktetgen',
  'vmtktetringenerator'
  ]

for item in __all__:
        exec('from '+item+' import *')

==> vmtk_1.0.1.orig.tar.gz: vmtk-1.0.1/vmtkScripts/vmtkscripts.py <==
__all__ = [
  'vmtkactivetubes',
  'vmtkbifurcationprofiles',
  'vmtkbifurcationreferencesystems',
  'vmtkbifurcationsections',
  'vmtkbifurcationvectors',
  'vmtkboundarylayer',
  'vmtkboundaryreferencesystems',
  'vmtkbranchclipper',
  'vmtkbranchextractor',
  'vmtkbranchgeometry',
  'vmtkbranchmapping',
  'vmtkbranchmetrics',
  'vmtkbranchpatching',
  'vmtkbranchsections',
  'vmtkcenterlineattributes',
  'vmtkcenterlinegeometry',
  'vmtkcenterlinelabeler',
  'vmtkcenterlinemerge',
  'vmtkcenterlinemodeller',
  'vmtkcenterlineoffsetattributes',
  'vmtkcenterlineresampling',
  'vmtkcenterlines',
  'vmtkcenterlinesections',
  'vmtkcenterlinesmoothing',
  'vmtkcenterlineviewer',
  'vmtkdelaunayvoronoi',
  'vmtkdistancetocenterlines',
  'vmtkendpointextractor',
  'vmtkflowextensions',
  'vmtkicpregistration',
  'vmtkimagecast',
  'vmtkimagecompose',
  'vmtkimagecurvedmpr',
  'vmtkimagefeaturecorrection',
  'vmtkimagefeatures',
  'vmtkimageinitialization',
  'vmtkimagelinetracer',
  'vmtkimagemipviewer',
  'vmtkimageobjectenhancement',
  'vmtkimagereader',
  'vmtkimagereslice',
  'vmtkimageseeder',
  'vmtkimageshiftscale',
  'vmtkimagesmoothing',
  'vmtkimageviewer',
  'vmtkimagevesselenhancement',
  'vmtkimagevoipainter',
  'vmtkimagevoiselector',
  'vmtkimagewriter',
  'vmtklevelsetsegmentation',
  'vmtklineartoquadratic',
  'vmtklineresampling',
  'vmtklocalgeometry',
  'vmtkmarchingcubes',
  'vmtkmeshboundaryinspector',
  'vmtkmeshbranchclipper',
  'vmtkmeshclipper',
  'vmtkmeshdatareader',
  'vmtkmeshlambda2',
  'vmtkmeshlinearize',
  'vmtkmeshgenerator',
  'vmtkmeshprojection',
  'vmtkmeshreader',
  'vmtkmeshscaling',
  'vmtkmeshtetrahedralize',
  'vmtkmeshtosurface',
  'vmtkmeshtransform',
  'vmtkmeshtransformtoras',
  'vmtkmeshvectorfromcomponents',
  'vmtkmeshviewer',
  'vmtkmeshvorticityhelicity',
  'vmtkmeshwallshearrate',
  'vmtkmeshwriter',
  'vmtknetworkeditor',
  'vmtknetworkextraction',
  'vmtknetworkwriter',
  'vmtkpointsplitextractor',
  'vmtkpointtransform',
  'vmtkpolyballmodeller',
  'vmtkpotentialfit',
  'vmtkpythonscript',
  'vmtkrenderer',
  'vmtkrendertoimage',
  'vmtkrbfinterpolation',
  'vmtksurfaceappend',
  'vmtksurfacecapper',
  'vmtksurfacecelldatatopointdata',
  'vmtksurfacecenterlineprojection',
  'vmtksurfaceclipper',
  'vmtksurfaceconnectivity',
  'vmtksurfacedecimation',
  'vmtksurfacedistance',
  'vmtksurfacekiteremoval',
  'vmtksurfacemodeller',
  'vmtksurfacenormals',
  'vmtksurfacepointdatatocelldata',
  'vmtksurfaceprojection',
  'vmtksurfacereader',
  'vmtksurfacereferencesystemtransform',
  'vmtksurfaceremeshing',
  'vmtksurfacescaling',
  'vmtksurfacesmoothing',
  'vmtksurfacesubdivision',
  'vmtksurfacetransform',
  'vmtksurfacetransforminteractive',
  'vmtksurfacetransformtoras',
  'vmtksurfacetriangle',
  'vmtksurfacetomesh',
  'vmtksurfaceviewer',
  'vmtksurfacewriter',
  'vmtksurfmesh',
  'vmtktetgen',
  'vmtktetringenerator'
  ]

for item in __all__:
        exec('from '+item+' import *')
